@@ -22,24 +22,24 @@
 #include "config.h"
 #endif /* HAVE_CONFIG_H */
 
+#include <arpa/inet.h>
 #include <errno.h>
-#include <sys/param.h>
+#include <stdarg.h>
 #include <stdlib.h>
 #include <string.h>
-#include <stdarg.h>
-#include <arpa/inet.h>
+#include <sys/param.h>
 
-#include <atalk/logger.h>
 #include <atalk/adouble.h>
-#include <atalk/util.h>
-#include <atalk/unix.h>
-#include <atalk/ea.h>
-#include <atalk/bstrlib.h>
 #include <atalk/bstradd.h>
+#include <atalk/bstrlib.h>
 #include <atalk/compat.h>
-#include <atalk/errchk.h>
-#include <atalk/volume.h>
 #include <atalk/dsi.h>
+#include <atalk/ea.h>
+#include <atalk/errchk.h>
+#include <atalk/logger.h>
+#include <atalk/unix.h>
+#include <atalk/util.h>
+#include <atalk/volume.h>
 
 #include "ad_lock.h"
 
@@ -148,6 +148,15 @@ static int ad_conv_v22ea_rf(const char *path, const struct stat *sp, const struc
     ad_init(&adea, vol);
     ad_init_old(&adv2, AD_VERSION2, adea.ad_options);
 
+    size_t copybuf_len = 0;
+    char* copybuf;
+
+    if (vol->v_obj->proto == AFPPROTO_DSI)
+    {
+        copybuf = vol->v_obj->dsi->commands;
+        copybuf_len = vol->v_obj->dsi->server_quantum;
+    }
+
     /* Open and lock adouble:v2 file */
     EC_ZERO( ad_open(&adv2, path, ADFLAGS_HF | ADFLAGS_RF | ADFLAGS_RDWR) );
 
@@ -158,8 +167,8 @@ static int ad_conv_v22ea_rf(const char *path, const struct stat *sp, const struc
         EC_ZERO_LOG( ad_open(&adea, path, ADFLAGS_RF|ADFLAGS_RDWR|ADFLAGS_CREATE|ADFLAGS_SETSHRMD, 0666) );
 
         EC_ZERO_LOG( copy_fork(ADEID_RFORK, &adea, &adv2,
-			       vol->v_obj->dsi->commands,
-			       vol->v_obj->dsi->server_quantum) );
+			       copybuf,
+			       copybuf_len) );
 
         adea.ad_rlen = adv2.ad_rlen;
         ad_flush(&adea);
@@ -236,7 +245,7 @@ static int ad_conv_dehex(const char *path, const struct stat *sp, const struct v
 
     EC_ZERO( bfindreplace(newpath, str2e, strdot, 0) );
     EC_ZERO( bfindreplace(newpath, str2f, strcolon, 0) );
-    
+
     become_root();
     if (adflags != ADFLAGS_DIR) {
         if ((newadpath = strdup(vol->ad_path(bdata(newpath), 0))) == NULL) {
